@@ -66,17 +66,21 @@ mixgb_save <- function(Obs.m, matrix.method, cbind.types, all.idx,
       dobs <- xgb.DMatrix(data = obs.data, label = obs.y, nthread = nthread)
       dmis <- xgb.DMatrix(data = mis.data, nthread = nthread)
       if (is.null(early_stopping_rounds)) {
-        watchlist <- list(train = dobs)
+        evals <- list(train = dobs)
       } else {
-        watchlist <- list(train = dobs)
+        evals <- list(train = dobs)
         # to be done, have eval
-        # watchlist <- list(train = dobs,eval=dmis)
+        # evals <- list(train = dobs,eval=dmis)
       }
 
 
       obj.type <- "reg:squarederror"
+      xgb.params$objective <- obj.type
+      xgb.params$eval_metric <- "rmse"
+      xgb.params$num_class <- NULL
+
       xgb.fit <- xgb.train(
-        data = dobs, objective = obj.type, watchlist = watchlist,
+        data = dobs,evals = evals,
         params = xgb.params, nrounds = nrounds, early_stopping_rounds = early_stopping_rounds,
         print_every_n = print_every_n, verbose = verbose, ...
       )
@@ -101,17 +105,21 @@ mixgb_save <- function(Obs.m, matrix.method, cbind.types, all.idx,
       dobs <- xgb.DMatrix(data = obs.data, label = obs.y, nthread = nthread)
       dmis <- xgb.DMatrix(data = mis.data, nthread = nthread)
       if (is.null(early_stopping_rounds)) {
-        watchlist <- list(train = dobs)
+        evals <- list(train = dobs)
       } else {
-        watchlist <- list(train = dobs)
+        evals <- list(train = dobs)
         # to be done, have eval
-        # watchlist <- list(train = dobs,eval=dmis)
+        # evals <- list(train = dobs,eval=dmis)
       }
 
 
       obj.type <- "reg:squarederror"
+      xgb.params$objective <- obj.type
+      xgb.params$eval_metric <- "rmse"
+      xgb.params$num_class <- NULL
+
       xgb.fit <- xgb.train(
-        data = dobs, objective = obj.type, watchlist = watchlist,
+        data = dobs, evals = evals,
         params = xgb.params, nrounds = nrounds, early_stopping_rounds = early_stopping_rounds,
         print_every_n = print_every_n, verbose = verbose, ...
       )
@@ -144,11 +152,11 @@ mixgb_save <- function(Obs.m, matrix.method, cbind.types, all.idx,
       dobs <- xgb.DMatrix(data = obs.data, label = obs.y, nthread = nthread)
       dmis <- xgb.DMatrix(data = mis.data, nthread = nthread)
       if (is.null(early_stopping_rounds)) {
-        watchlist <- list(train = dobs)
+        evals <- list(train = dobs)
       } else {
-        watchlist <- list(train = dobs)
+        evals <- list(train = dobs)
         # to be done, have eval
-        # watchlist <- list(train = dobs,eval=dmis)
+        # evals <- list(train = dobs,eval=dmis)
       }
       # when bin.t has two values: bin.t[1] minority class & bin.t[2] majority class
       # when bin.t only has one value: bin.t[1] the only existent class
@@ -172,9 +180,11 @@ mixgb_save <- function(Obs.m, matrix.method, cbind.types, all.idx,
           # pmm by "prob" and for no pmm
           obj.type <- "binary:logistic"
         }
+        xgb.params$objective <- obj.type
+        xgb.params$eval_metric<- "logloss"
+        xgb.params$num_class <- NULL
         xgb.fit <- xgb.train(
-          data = dobs, objective = obj.type, watchlist = watchlist,
-          eval_metric = "logloss",
+          data = dobs,  evals = evals,
           params = xgb.params, nrounds = nrounds, early_stopping_rounds = early_stopping_rounds,
           print_every_n = print_every_n, verbose = verbose, ...
         )
@@ -207,11 +217,11 @@ mixgb_save <- function(Obs.m, matrix.method, cbind.types, all.idx,
       dobs <- xgb.DMatrix(data = obs.data, label = obs.y, nthread = nthread)
       dmis <- xgb.DMatrix(data = mis.data, nthread = nthread)
       if (is.null(early_stopping_rounds)) {
-        watchlist <- list(train = dobs)
+        evals <- list(train = dobs)
       } else {
-        watchlist <- list(train = dobs)
+        evals <- list(train = dobs)
         # to be done, have eval
-        # watchlist <- list(train = dobs,eval=dmis)
+        # evals <- list(train = dobs,eval=dmis)
       }
 
 
@@ -224,7 +234,6 @@ mixgb_save <- function(Obs.m, matrix.method, cbind.types, all.idx,
         yhatmis <- as.logical(names(bin.t[1]))
         sorted.dt[na.idx, (var) := yhatmis]
 
-
         # save models=the only class exist in the sample
         xgb.models[[var]] <- yhatmis
         yhatobs.list[[var]] <- rep(yhatmis, length(yobs.list[[var]]))
@@ -238,9 +247,11 @@ mixgb_save <- function(Obs.m, matrix.method, cbind.types, all.idx,
           # pmm by "prob" and for no pmm
           obj.type <- "binary:logistic"
         }
+        xgb.params$objective <- obj.type
+        xgb.params$eval_metric<- "logloss"
+        xgb.params$num_class <- NULL
         xgb.fit <- xgb.train(
-          data = dobs, objective = obj.type, watchlist = watchlist,
-          eval_metric = "logloss",
+          data = dobs, evals = evals,
           params = xgb.params, nrounds = nrounds, early_stopping_rounds = early_stopping_rounds,
           print_every_n = print_every_n, verbose = verbose, ...
         )
@@ -273,11 +284,11 @@ mixgb_save <- function(Obs.m, matrix.method, cbind.types, all.idx,
       dmis <- xgb.DMatrix(data = mis.data, nthread = nthread)
 
       if (is.null(early_stopping_rounds)) {
-        watchlist <- list(train = dobs)
+        evals <- list(train = dobs)
       } else {
-        watchlist <- list(train = dobs)
+        evals <- list(train = dobs)
         # to be done, have eval
-        # watchlist <- list(train = dobs,eval=dmis)
+        # evals <- list(train = dobs,eval=dmis)
       }
 
       if (is.null(pmm.type) | isTRUE(pmm.type == "auto")) {
@@ -286,12 +297,15 @@ mixgb_save <- function(Obs.m, matrix.method, cbind.types, all.idx,
         # use probability to do matching
         obj.type <- "multi:softprob"
       }
+      xgb.params$objective <- obj.type
+      xgb.params$eval_metric<- "mlogloss"
+
       N.class <- length(levels(sorted.dt[[var]]))
+      xgb.params$num_class = N.class
 
       xgb.fit <- xgb.train(
-        data = dobs, num_class = N.class,
-        objective = obj.type, watchlist = watchlist,
-        eval_metric = "mlogloss",
+        data = dobs,
+        evals = evals,
         params = xgb.params, nrounds = nrounds, early_stopping_rounds = early_stopping_rounds,
         print_every_n = print_every_n, verbose = verbose, ...
       )
@@ -306,14 +320,14 @@ mixgb_save <- function(Obs.m, matrix.method, cbind.types, all.idx,
         sorted.dt[na.idx, (var) := yhatmis]
       } else {
         # predict returns probability matrix for each class
-        yhatmis <- predict(xgb.fit, dmis, reshape = TRUE)
+        yhatmis <- predict(xgb.fit, dmis)
         if (pmm.type == 1) {
           # for pmm.type=1
           yhatobs <- yhatobs.list[[var]]
         } else {
           # for pmm.type=0 or 2
           # probability matrix for each class
-          yhatobs <- predict(xgb.fit, dobs, reshape = TRUE)
+          yhatobs <- predict(xgb.fit, dobs)
           yhatobs.list[[var]] <- yhatobs
         }
 
@@ -381,16 +395,20 @@ mixgb_save <- function(Obs.m, matrix.method, cbind.types, all.idx,
         dobs <- xgb.DMatrix(data = obs.data, label = obs.y, nthread = nthread)
 
         if (is.null(early_stopping_rounds)) {
-          watchlist <- list(train = dobs)
+          evals <- list(train = dobs)
         } else {
-          watchlist <- list(train = dobs)
+          evals <- list(train = dobs)
           # to be done, have eval
-          # watchlist <- list(train = dobs,eval=dmis)
+          # evals <- list(train = dobs,eval=dmis)
         }
 
         obj.type <- "reg:squarederror"
+        xgb.params$objective <- obj.type
+        xgb.params$eval_metric <- "rmse"
+        xgb.params$num_class <- NULL
+
         xgb.fit <- xgb.train(
-          data = dobs, objective = obj.type, watchlist = watchlist,
+          data = dobs, evals = evals,
           params = xgb.params, nrounds = nrounds, early_stopping_rounds = early_stopping_rounds,
           print_every_n = print_every_n, verbose = verbose, ...
         )
@@ -406,11 +424,11 @@ mixgb_save <- function(Obs.m, matrix.method, cbind.types, all.idx,
         bin.t <- sort(table(obs.y))
         dobs <- xgb.DMatrix(data = obs.data, label = obs.y, nthread = nthread)
         if (is.null(early_stopping_rounds)) {
-          watchlist <- list(train = dobs)
+          evals <- list(train = dobs)
         } else {
-          watchlist <- list(train = dobs)
+          evals <- list(train = dobs)
           # to be done, have eval
-          # watchlist <- list(train = dobs,eval=dmis)
+          # evals <- list(train = dobs,eval=dmis)
         }
         # when bin.t has two values: bin.t[1] minority class & bin.t[2] majority class
         # when bin.t only has one value: bin.t[1] the only existent class
@@ -428,9 +446,11 @@ mixgb_save <- function(Obs.m, matrix.method, cbind.types, all.idx,
             # pmm by "prob" value
             obj.type <- "binary:logistic"
           }
+          xgb.params$objective <- obj.type
+          xgb.params$eval_metric<- "logloss"
+          xgb.params$num_class <- NULL
           xgb.fit <- xgb.train(
-            data = dobs, objective = obj.type, watchlist = watchlist,
-            eval_metric = "logloss",
+            data = dobs, evals = evals,
             params = xgb.params, nrounds = nrounds, early_stopping_rounds = early_stopping_rounds,
             print_every_n = print_every_n, verbose = verbose, ...
           )
@@ -446,11 +466,11 @@ mixgb_save <- function(Obs.m, matrix.method, cbind.types, all.idx,
         dobs <- xgb.DMatrix(data = obs.data, label = obs.y, nthread = nthread)
 
         if (is.null(early_stopping_rounds)) {
-          watchlist <- list(train = dobs)
+          evals <- list(train = dobs)
         } else {
-          watchlist <- list(train = dobs)
+          evals <- list(train = dobs)
           # to be done, have eval
-          # watchlist <- list(train = dobs,eval=dmis)
+          # evals <- list(train = dobs,eval=dmis)
         }
 
         bin.t <- sort(table(obs.y))
@@ -472,9 +492,11 @@ mixgb_save <- function(Obs.m, matrix.method, cbind.types, all.idx,
             # pmm by "prob" value
             obj.type <- "binary:logistic"
           }
+          xgb.params$objective <- obj.type
+          xgb.params$eval_metric<- "logloss"
+          xgb.params$num_class <- NULL
           xgb.fit <- xgb.train(
-            data = dobs, objective = obj.type, watchlist = watchlist,
-            eval_metric = "logloss",
+            data = dobs, evals = evals,
             params = xgb.params, nrounds = nrounds, early_stopping_rounds = early_stopping_rounds,
             print_every_n = print_every_n, verbose = verbose, ...
           )
@@ -491,11 +513,11 @@ mixgb_save <- function(Obs.m, matrix.method, cbind.types, all.idx,
         obs.y <- as.integer(obs.y) - 1
         dobs <- xgb.DMatrix(data = obs.data, label = obs.y, nthread = nthread)
         if (is.null(early_stopping_rounds)) {
-          watchlist <- list(train = dobs)
+          evals <- list(train = dobs)
         } else {
-          watchlist <- list(train = dobs)
+          evals <- list(train = dobs)
           # to be done, have eval
-          # watchlist <- list(train = dobs,eval=dmis)
+          # evals <- list(train = dobs,eval=dmis)
         }
 
 
@@ -505,12 +527,14 @@ mixgb_save <- function(Obs.m, matrix.method, cbind.types, all.idx,
           # use probability to do matching
           obj.type <- "multi:softprob"
         }
-
+        xgb.params$objective <- obj.type
+        xgb.params$eval_metric<- "mlogloss"
         N.class <- length(levels(sorted.dt[[var]]))
+        xgb.params$num_class = N.class
+
         xgb.fit <- xgb.train(
-          data = dobs, num_class = N.class,
-          objective = obj.type, watchlist = watchlist,
-          eval_metric = "mlogloss",
+          data = dobs,
+          evals = evals,
           params = xgb.params, nrounds = nrounds, early_stopping_rounds = early_stopping_rounds,
           print_every_n = print_every_n, verbose = verbose, ...
         )
@@ -520,7 +544,7 @@ mixgb_save <- function(Obs.m, matrix.method, cbind.types, all.idx,
 
         # prediction returns probability for matching: probability matrix for each class
         if (isTRUE(pmm.type == 0) | isTRUE(pmm.type == 2)) {
-          yhatobs.list[[var]] <- predict(xgb.fit, dobs, reshape = TRUE)
+          yhatobs.list[[var]] <- predict(xgb.fit, dobs)
         }
       }
     } # end of for each extra variable
