@@ -69,17 +69,20 @@ mixgb_xgb_save <- function(Obs.m, matrix.method, cbind.types, all.idx,
       dobs <- xgb.DMatrix(data = obs.data, label = obs.y, nthread = nthread)
       dmis <- xgb.DMatrix(data = mis.data, nthread = nthread)
       if (is.null(early_stopping_rounds)) {
-        watchlist <- list(train = dobs)
+        evals <- list(train = dobs)
       } else {
-        watchlist <- list(train = dobs)
+        evals <- list(train = dobs)
         # to be done, have eval
-        # watchlist <- list(train = dobs,eval=dmis)
+        # evals <- list(train = dobs,eval=dmis)
       }
 
 
       obj.type <- "reg:squarederror"
+      xgb.params$objective <- obj.type
+      xgb.params$eval_metric <- "rmse"
+      xgb.params$num_class <- NULL
       xgb.fit <- xgb.train(
-        data = dobs, objective = obj.type, watchlist = watchlist,
+        data = dobs, evals = evals,
         params = xgb.params, nrounds = nrounds, early_stopping_rounds = early_stopping_rounds,
         print_every_n = print_every_n, verbose = verbose, ...
       )
@@ -107,17 +110,21 @@ mixgb_xgb_save <- function(Obs.m, matrix.method, cbind.types, all.idx,
       dobs <- xgb.DMatrix(data = obs.data, label = obs.y, nthread = nthread)
       dmis <- xgb.DMatrix(data = mis.data, nthread = nthread)
       if (is.null(early_stopping_rounds)) {
-        watchlist <- list(train = dobs)
+        evals <- list(train = dobs)
       } else {
-        watchlist <- list(train = dobs)
+        evals <- list(train = dobs)
         # to be done, have eval
-        # watchlist <- list(train = dobs,eval=dmis)
+        # evals <- list(train = dobs,eval=dmis)
       }
 
 
       obj.type <- "reg:squarederror"
+      xgb.params$objective <- obj.type
+      xgb.params$eval_metric <- "rmse"
+      xgb.params$num_class <- NULL
+
       xgb.fit <- xgb.train(
-        data = dobs, objective = obj.type, watchlist = watchlist,
+        data = dobs, evals = evals,
         params = xgb.params, nrounds = nrounds, early_stopping_rounds = early_stopping_rounds,
         print_every_n = print_every_n, verbose = verbose, ...
       )
@@ -153,11 +160,11 @@ mixgb_xgb_save <- function(Obs.m, matrix.method, cbind.types, all.idx,
       dobs <- xgb.DMatrix(data = obs.data, label = obs.y, nthread = nthread)
       dmis <- xgb.DMatrix(data = mis.data, nthread = nthread)
       if (is.null(early_stopping_rounds)) {
-        watchlist <- list(train = dobs)
+        evals <- list(train = dobs)
       } else {
-        watchlist <- list(train = dobs)
+        evals <- list(train = dobs)
         # to be done, have eval
-        # watchlist <- list(train = dobs,eval=dmis)
+        # evals <- list(train = dobs,eval=dmis)
       }
       # when bin.t has two values: bin.t[1] minority class & bin.t[2] majority class
       # when bin.t only has one value: bin.t[1] the only existent class
@@ -181,9 +188,11 @@ mixgb_xgb_save <- function(Obs.m, matrix.method, cbind.types, all.idx,
           # pmm by "prob" and for no pmm
           obj.type <- "binary:logistic"
         }
+        xgb.params$objective <- obj.type
+        xgb.params$eval_metric<- "logloss"
+        xgb.params$num_class <- NULL
         xgb.fit <- xgb.train(
-          data = dobs, objective = obj.type, watchlist = watchlist,
-          eval_metric = "logloss",
+          data = dobs,  evals = evals,
           params = xgb.params, nrounds = nrounds, early_stopping_rounds = early_stopping_rounds,
           print_every_n = print_every_n, verbose = verbose, ...
         )
@@ -219,11 +228,11 @@ mixgb_xgb_save <- function(Obs.m, matrix.method, cbind.types, all.idx,
       dobs <- xgb.DMatrix(data = obs.data, label = obs.y, nthread = nthread)
       dmis <- xgb.DMatrix(data = mis.data, nthread = nthread)
       if (is.null(early_stopping_rounds)) {
-        watchlist <- list(train = dobs)
+        evals <- list(train = dobs)
       } else {
-        watchlist <- list(train = dobs)
+        evals <- list(train = dobs)
         # to be done, have eval
-        # watchlist <- list(train = dobs,eval=dmis)
+        # evals <- list(train = dobs,eval=dmis)
       }
 
 
@@ -250,9 +259,11 @@ mixgb_xgb_save <- function(Obs.m, matrix.method, cbind.types, all.idx,
           # pmm by "prob" and for no pmm
           obj.type <- "binary:logistic"
         }
+        xgb.params$objective <- obj.type
+        xgb.params$eval_metric<- "logloss"
+        xgb.params$num_class <- NULL
         xgb.fit <- xgb.train(
-          data = dobs, objective = obj.type, watchlist = watchlist,
-          eval_metric = "logloss",
+          data = dobs,  evals = evals,
           params = xgb.params, nrounds = nrounds, early_stopping_rounds = early_stopping_rounds,
           print_every_n = print_every_n, verbose = verbose, ...
         )
@@ -288,11 +299,11 @@ mixgb_xgb_save <- function(Obs.m, matrix.method, cbind.types, all.idx,
       dmis <- xgb.DMatrix(data = mis.data, nthread = nthread)
 
       if (is.null(early_stopping_rounds)) {
-        watchlist <- list(train = dobs)
+        evals <- list(train = dobs)
       } else {
-        watchlist <- list(train = dobs)
+        evals <- list(train = dobs)
         # to be done, have eval
-        # watchlist <- list(train = dobs,eval=dmis)
+        # evals <- list(train = dobs,eval=dmis)
       }
 
       if (is.null(pmm.type) | isTRUE(pmm.type == "auto")) {
@@ -301,12 +312,14 @@ mixgb_xgb_save <- function(Obs.m, matrix.method, cbind.types, all.idx,
         # use probability to do matching
         obj.type <- "multi:softprob"
       }
+      xgb.params$objective <- obj.type
+      xgb.params$eval_metric<- "mlogloss"
       N.class <- length(levels(sorted.dt[[var]]))
+      xgb.params$num_class = N.class
 
       xgb.fit <- xgb.train(
-        data = dobs, num_class = N.class,
-        objective = obj.type, watchlist = watchlist,
-        eval_metric = "mlogloss",
+        data = dobs,
+        evals = evals,
         params = xgb.params, nrounds = nrounds, early_stopping_rounds = early_stopping_rounds,
         print_every_n = print_every_n, verbose = verbose, ...
       )
@@ -324,14 +337,14 @@ mixgb_xgb_save <- function(Obs.m, matrix.method, cbind.types, all.idx,
         sorted.dt[na.idx, (var) := yhatmis]
       } else {
         # predict returns probability matrix for each class
-        yhatmis <- predict(xgb.fit, dmis, reshape = TRUE)
+        yhatmis <- predict(xgb.fit, dmis)
         if (pmm.type == 1) {
           # for pmm.type=1
           yhatobs <- yhatobs.list[[var]]
         } else {
           # for pmm.type=0 or 2
           # probability matrix for each class
-          yhatobs <- predict(xgb.fit, dobs, reshape = TRUE)
+          yhatobs <- predict(xgb.fit, dobs)
           yhatobs.list[[var]] <- yhatobs
         }
 
@@ -399,16 +412,20 @@ mixgb_xgb_save <- function(Obs.m, matrix.method, cbind.types, all.idx,
         dobs <- xgb.DMatrix(data = obs.data, label = obs.y, nthread = nthread)
 
         if (is.null(early_stopping_rounds)) {
-          watchlist <- list(train = dobs)
+          evals <- list(train = dobs)
         } else {
-          watchlist <- list(train = dobs)
+          evals <- list(train = dobs)
           # to be done, have eval
-          # watchlist <- list(train = dobs,eval=dmis)
+          # evals <- list(train = dobs,eval=dmis)
         }
 
         obj.type <- "reg:squarederror"
+        xgb.params$objective <- obj.type
+        xgb.params$eval_metric <- "rmse"
+        xgb.params$num_class <- NULL
+
         xgb.fit <- xgb.train(
-          data = dobs, objective = obj.type, watchlist = watchlist,
+          data = dobs, evals = evals,
           params = xgb.params, nrounds = nrounds, early_stopping_rounds = early_stopping_rounds,
           print_every_n = print_every_n, verbose = verbose, ...
         )
@@ -426,11 +443,11 @@ mixgb_xgb_save <- function(Obs.m, matrix.method, cbind.types, all.idx,
         bin.t <- sort(table(obs.y))
         dobs <- xgb.DMatrix(data = obs.data, label = obs.y, nthread = nthread)
         if (is.null(early_stopping_rounds)) {
-          watchlist <- list(train = dobs)
+          evals <- list(train = dobs)
         } else {
-          watchlist <- list(train = dobs)
+          evals <- list(train = dobs)
           # to be done, have eval
-          # watchlist <- list(train = dobs,eval=dmis)
+          # evals <- list(train = dobs,eval=dmis)
         }
         # when bin.t has two values: bin.t[1] minority class & bin.t[2] majority class
         # when bin.t only has one value: bin.t[1] the only existent class
@@ -448,9 +465,11 @@ mixgb_xgb_save <- function(Obs.m, matrix.method, cbind.types, all.idx,
             # pmm by "prob" value
             obj.type <- "binary:logistic"
           }
+          xgb.params$objective <- obj.type
+          xgb.params$eval_metric<- "logloss"
+          xgb.params$num_class <- NULL
           xgb.fit <- xgb.train(
-            data = dobs, objective = obj.type, watchlist = watchlist,
-            eval_metric = "logloss",
+            data = dobs, evals = evals,
             params = xgb.params, nrounds = nrounds, early_stopping_rounds = early_stopping_rounds,
             print_every_n = print_every_n, verbose = verbose, ...
           )
@@ -468,11 +487,11 @@ mixgb_xgb_save <- function(Obs.m, matrix.method, cbind.types, all.idx,
         dobs <- xgb.DMatrix(data = obs.data, label = obs.y, nthread = nthread)
 
         if (is.null(early_stopping_rounds)) {
-          watchlist <- list(train = dobs)
+          evals <- list(train = dobs)
         } else {
-          watchlist <- list(train = dobs)
+          evals <- list(train = dobs)
           # to be done, have eval
-          # watchlist <- list(train = dobs,eval=dmis)
+          # evals <- list(train = dobs,eval=dmis)
         }
 
         bin.t <- sort(table(obs.y))
@@ -494,9 +513,11 @@ mixgb_xgb_save <- function(Obs.m, matrix.method, cbind.types, all.idx,
             # pmm by "prob" value
             obj.type <- "binary:logistic"
           }
+          xgb.params$objective <- obj.type
+          xgb.params$eval_metric<- "logloss"
+          xgb.params$num_class <- NULL
           xgb.fit <- xgb.train(
-            data = dobs, objective = obj.type, watchlist = watchlist,
-            eval_metric = "logloss",
+            data = dobs,  evals = evals,
             params = xgb.params, nrounds = nrounds, early_stopping_rounds = early_stopping_rounds,
             print_every_n = print_every_n, verbose = verbose, ...
           )
@@ -515,11 +536,11 @@ mixgb_xgb_save <- function(Obs.m, matrix.method, cbind.types, all.idx,
         obs.y <- as.integer(obs.y) - 1
         dobs <- xgb.DMatrix(data = obs.data, label = obs.y, nthread = nthread)
         if (is.null(early_stopping_rounds)) {
-          watchlist <- list(train = dobs)
+          evals <- list(train = dobs)
         } else {
-          watchlist <- list(train = dobs)
+          evals <- list(train = dobs)
           # to be done, have eval
-          # watchlist <- list(train = dobs,eval=dmis)
+          # evals <- list(train = dobs,eval=dmis)
         }
 
 
@@ -529,12 +550,14 @@ mixgb_xgb_save <- function(Obs.m, matrix.method, cbind.types, all.idx,
           # use probability to do matching
           obj.type <- "multi:softprob"
         }
-
+        xgb.params$objective <- obj.type
+        xgb.params$eval_metric<- "mlogloss"
         N.class <- length(levels(sorted.dt[[var]]))
+        xgb.params$num_class = N.class
+
         xgb.fit <- xgb.train(
-          data = dobs, num_class = N.class,
-          objective = obj.type, watchlist = watchlist,
-          eval_metric = "mlogloss",
+          data = dobs,
+          evals = evals,
           params = xgb.params, nrounds = nrounds, early_stopping_rounds = early_stopping_rounds,
           print_every_n = print_every_n, verbose = verbose, ...
         )
@@ -546,7 +569,7 @@ mixgb_xgb_save <- function(Obs.m, matrix.method, cbind.types, all.idx,
 
         # prediction returns probability for matching: probability matrix for each class
         if (isTRUE(pmm.type == 0) | isTRUE(pmm.type == 2)) {
-          yhatobs.list[[var]] <- predict(xgb.fit, dobs, reshape = TRUE)
+          yhatobs.list[[var]] <- predict(xgb.fit, dobs)
         }
       }
     } # end of for each extra variable
